# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["UserVerifyEmailResponse"]


class UserVerifyEmailResponse(BaseModel):
    detail: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Union, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel
from .embedder_config import EmbedderConfig
from .reranker_config import RerankerConfig
from .query_llm_config import QueryLlmConfig
from .retriever_config import RetrieverConfig
from .title_llm_config import TitleLlmConfig
from .model_citation_config import ModelCitationConfig
from .document_date_extractor_llm_config import DocumentDateExtractorLlmConfig

__all__ = [
    "ConfigRetrieveResponse",
    "AllConfigs",
    "AllConfigsAgentLlm",
    "AllConfigsAgents",
    "AllConfigsDocumentSummaryExtractorLlm",
    "AllConfigsEvaluatorLlm",
    "NonDeveloperConfig",
]


class AllConfigsAgentLlm(BaseModel):
    api_type: Optional[Literal["local", "remote"]] = FieldInfo(alias="API_TYPE", default=None)
    """The inference type (local or remote)."""

    enabled: Optional[bool] = FieldInfo(alias="ENABLED", default=None)
    """Whether to use agent mode for queries."""

    max_char_size_to_answer: Optional[int] = FieldInfo(alias="MAX_CHAR_SIZE_TO_ANSWER", default=None)
    """Maximum character size for history."""

    max_context_tokens: Optional[int] = FieldInfo(alias="MAX_CONTEXT_TOKENS", default=None)
    """
    Maximum tokens for gathered context (applies to evidence buffer and final
    query).
    """

    max_iterations: Optional[int] = FieldInfo(alias="MAX_ITERATIONS", default=None)
    """Maximum agent loop iterations."""

    max_tokens: Optional[int] = FieldInfo(alias="MAX_TOKENS", default=None)
    """Maximum tokens for planning decisions."""

    api_model_name: Optional[str] = FieldInfo(alias="MODEL_NAME", default=None)
    """The name of the model to be used."""

    show_interim_steps: Optional[bool] = FieldInfo(alias="SHOW_INTERIM_STEPS", default=None)
    """Whether to show agent's intermediate steps."""

    system_instruction: Optional[str] = FieldInfo(alias="SYSTEM_INSTRUCTION", default=None)
    """The system instruction for agent planning."""

    temperature: Optional[float] = FieldInfo(alias="TEMPERATURE", default=None)
    """Temperature for agent decisions."""


class AllConfigsAgents(BaseModel):
    agent_model_name: Optional[str] = FieldInfo(alias="AGENT_MODEL_NAME", default=None)
    """The name of the model to be used for the agent."""

    agent_prompt: Optional[str] = FieldInfo(alias="AGENT_PROMPT", default=None)

    enabled: Optional[bool] = FieldInfo(alias="ENABLED", default=None)
    """Whether to use agents mode for queries."""

    llm_page_filter_model_name: Optional[str] = FieldInfo(alias="LLM_PAGE_FILTER_MODEL_NAME", default=None)
    """The name of the model to be used for the llm page filter model."""

    llm_page_filter_prompt: Optional[str] = FieldInfo(alias="LLM_PAGE_FILTER_PROMPT", default=None)

    llm_page_filter_temperature: Optional[float] = FieldInfo(alias="LLM_PAGE_FILTER_TEMPERATURE", default=None)
    """Temperature value for randomness."""

    llm_summarise_model_name: Optional[str] = FieldInfo(alias="LLM_SUMMARISE_MODEL_NAME", default=None)
    """The name of the model to be used for the llm summarise model."""

    llm_summarise_prompt: Optional[str] = FieldInfo(alias="LLM_SUMMARISE_PROMPT", default=None)

    llm_summarise_temperature: Optional[float] = FieldInfo(alias="LLM_SUMMARISE_TEMPERATURE", default=None)
    """Temperature value for randomness."""


class AllConfigsDocumentSummaryExtractorLlm(BaseModel):
    api_type: Optional[Literal["local", "remote"]] = FieldInfo(alias="API_TYPE", default=None)
    """The inference type (local or remote)."""

    max_char_context_to_answer: Optional[int] = FieldInfo(alias="MAX_CHAR_CONTEXT_TO_ANSWER", default=None)
    """Maximum characters in document for context."""

    max_tokens: Optional[int] = FieldInfo(alias="MAX_TOKENS", default=None)
    """Maximum number of tokens allowed."""

    api_model_name: Optional[str] = FieldInfo(alias="MODEL_NAME", default=None)
    """The name of the non-reasoning model to be used."""

    system_instruction: Optional[str] = FieldInfo(alias="SYSTEM_INSTRUCTION", default=None)

    temperature: Optional[float] = FieldInfo(alias="TEMPERATURE", default=None)
    """Temperature value for randomness."""


class AllConfigsEvaluatorLlm(BaseModel):
    api_type: Optional[Literal["local", "remote"]] = FieldInfo(alias="API_TYPE", default=None)
    """The inference type (local or remote)."""

    max_char_size_to_answer: Optional[int] = FieldInfo(alias="MAX_CHAR_SIZE_TO_ANSWER", default=None)
    """Maximum character size for evaluation context."""

    max_tokens: Optional[int] = FieldInfo(alias="MAX_TOKENS", default=None)
    """Maximum tokens for evaluation response."""

    api_model_name: Optional[str] = FieldInfo(alias="MODEL_NAME", default=None)
    """The name of the non-reasoning model to be used."""

    system_instruction: Optional[str] = FieldInfo(alias="SYSTEM_INSTRUCTION", default=None)
    """The system instruction for chunk evaluation."""

    temperature: Optional[float] = FieldInfo(alias="TEMPERATURE", default=None)
    """Low temperature for consistent evaluation."""


class AllConfigs(BaseModel):
    agent_llm: Optional[AllConfigsAgentLlm] = FieldInfo(alias="AgentLLM", default=None)

    agents: Optional[AllConfigsAgents] = FieldInfo(alias="Agents", default=None)

    chunker: Optional[object] = FieldInfo(alias="Chunker", default=None)

    document_date_extractor_llm: Optional[DocumentDateExtractorLlmConfig] = FieldInfo(
        alias="DocumentDateExtractorLLM", default=None
    )

    document_summary_extractor_llm: Optional[AllConfigsDocumentSummaryExtractorLlm] = FieldInfo(
        alias="DocumentSummaryExtractorLLM", default=None
    )

    embedder: Optional[EmbedderConfig] = FieldInfo(alias="Embedder", default=None)

    evaluator_llm: Optional[AllConfigsEvaluatorLlm] = FieldInfo(alias="EvaluatorLLM", default=None)

    api_model_citation: Optional[ModelCitationConfig] = FieldInfo(alias="ModelCitation", default=None)

    parser: Optional[object] = FieldInfo(alias="Parser", default=None)

    query_llm: Optional[QueryLlmConfig] = FieldInfo(alias="QueryLLM", default=None)

    reranker: Optional[RerankerConfig] = FieldInfo(alias="Reranker", default=None)

    retriever: Optional[RetrieverConfig] = FieldInfo(alias="Retriever", default=None)

    title_llm: Optional[TitleLlmConfig] = FieldInfo(alias="TitleLLM", default=None)


class NonDeveloperConfig(BaseModel):
    """Limited configuration response for non-developer users"""

    agent_llm: Dict[str, bool] = FieldInfo(alias="AgentLLM")

    query_llm: Dict[str, str] = FieldInfo(alias="QueryLLM")


ConfigRetrieveResponse: TypeAlias = Union[AllConfigs, NonDeveloperConfig]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["UserChangePasswordResponse"]


class UserChangePasswordResponse(BaseModel):
    detail: str

    workspaces_updated: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .user_add_params import UserAddParams as UserAddParams
from .user_add_response import UserAddResponse as UserAddResponse
from .user_remove_params import UserRemoveParams as UserRemoveParams
from .user_remove_response import UserRemoveResponse as UserRemoveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from ...._models import BaseModel

__all__ = ["DocTagResponse"]


class DocTagResponse(BaseModel):
    """Response for doctag operations - the link between a document and a tag."""

    created_at: datetime

    created_by_ext_id: str

    doc_ext_id: str

    tag_ext_id: str

    updated_at: datetime

    note: Optional[str] = None

    updated_by_ext_id: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from arbi import Arbi, AsyncArbi
from tests.utils import assert_matches_type
from arbi.types.api import (
    WorkspaceResponse,
    WorkspaceCopyResponse,
    WorkspaceShareResponse,
    WorkspaceDeleteResponse,
    WorkspaceGetTagsResponse,
    WorkspaceGetStatsResponse,
    WorkspaceGetUsersResponse,
    WorkspaceRemoveUserResponse,
    WorkspaceGetDocumentsResponse,
    WorkspaceGetConversationsResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestWorkspace:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: Arbi) -> None:
        workspace = client.api.workspace.update(
            workspace_ext_id="wrk",
        )
        assert_matches_type(WorkspaceResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Arbi) -> None:
        workspace = client.api.workspace.update(
            workspace_ext_id="wrk",
            description="description",
            is_public=True,
            name="name",
            workspace_key="workspace-key",
        )
        assert_matches_type(WorkspaceResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Arbi) -> None:
        response = client.api.workspace.with_raw_response.update(
            workspace_ext_id="wrk",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = response.parse()
        assert_matches_type(WorkspaceResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Arbi) -> None:
        with client.api.workspace.with_streaming_response.update(
            workspace_ext_id="wrk",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = response.parse()
            assert_matches_type(WorkspaceResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Arbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            client.api.workspace.with_raw_response.update(
                workspace_ext_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete(self, client: Arbi) -> None:
        workspace = client.api.workspace.delete(
            "wrk",
        )
        assert_matches_type(WorkspaceDeleteResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: Arbi) -> None:
        response = client.api.workspace.with_raw_response.delete(
            "wrk",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = response.parse()
        assert_matches_type(WorkspaceDeleteResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: Arbi) -> None:
        with client.api.workspace.with_streaming_response.delete(
            "wrk",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = response.parse()
            assert_matches_type(WorkspaceDeleteResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: Arbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            client.api.workspace.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_copy(self, client: Arbi) -> None:
        workspace = client.api.workspace.copy(
            workspace_ext_id="wrk",
            items=["string"],
            target_workspace_ext_id="wrk-bFXA5r3A",
        )
        assert_matches_type(WorkspaceCopyResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_copy_with_all_params(self, client: Arbi) -> None:
        workspace = client.api.workspace.copy(
            workspace_ext_id="wrk",
            items=["string"],
            target_workspace_ext_id="wrk-bFXA5r3A",
            target_workspace_key="target-workspace-key",
            workspace_key="workspace-key",
        )
        assert_matches_type(WorkspaceCopyResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_copy(self, client: Arbi) -> None:
        response = client.api.workspace.with_raw_response.copy(
            workspace_ext_id="wrk",
            items=["string"],
            target_workspace_ext_id="wrk-bFXA5r3A",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = response.parse()
        assert_matches_type(WorkspaceCopyResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_copy(self, client: Arbi) -> None:
        with client.api.workspace.with_streaming_response.copy(
            workspace_ext_id="wrk",
            items=["string"],
            target_workspace_ext_id="wrk-bFXA5r3A",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = response.parse()
            assert_matches_type(WorkspaceCopyResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_copy(self, client: Arbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            client.api.workspace.with_raw_response.copy(
                workspace_ext_id="",
                items=["string"],
                target_workspace_ext_id="wrk-bFXA5r3A",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_protected(self, client: Arbi) -> None:
        workspace = client.api.workspace.create_protected(
            name="name",
        )
        assert_matches_type(WorkspaceResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_protected_with_all_params(self, client: Arbi) -> None:
        workspace = client.api.workspace.create_protected(
            name="name",
            description="description",
            is_public=True,
        )
        assert_matches_type(WorkspaceResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create_protected(self, client: Arbi) -> None:
        response = client.api.workspace.with_raw_response.create_protected(
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = response.parse()
        assert_matches_type(WorkspaceResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create_protected(self, client: Arbi) -> None:
        with client.api.workspace.with_streaming_response.create_protected(
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = response.parse()
            assert_matches_type(WorkspaceResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_conversations(self, client: Arbi) -> None:
        workspace = client.api.workspace.get_conversations(
            "wrk",
        )
        assert_matches_type(WorkspaceGetConversationsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_conversations(self, client: Arbi) -> None:
        response = client.api.workspace.with_raw_response.get_conversations(
            "wrk",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = response.parse()
        assert_matches_type(WorkspaceGetConversationsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_conversations(self, client: Arbi) -> None:
        with client.api.workspace.with_streaming_response.get_conversations(
            "wrk",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = response.parse()
            assert_matches_type(WorkspaceGetConversationsResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_conversations(self, client: Arbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            client.api.workspace.with_raw_response.get_conversations(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_documents(self, client: Arbi) -> None:
        workspace = client.api.workspace.get_documents(
            workspace_ext_id="wrk",
        )
        assert_matches_type(WorkspaceGetDocumentsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_documents_with_all_params(self, client: Arbi) -> None:
        workspace = client.api.workspace.get_documents(
            workspace_ext_id="wrk",
            workspace_key="workspace-key",
        )
        assert_matches_type(WorkspaceGetDocumentsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_documents(self, client: Arbi) -> None:
        response = client.api.workspace.with_raw_response.get_documents(
            workspace_ext_id="wrk",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = response.parse()
        assert_matches_type(WorkspaceGetDocumentsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_documents(self, client: Arbi) -> None:
        with client.api.workspace.with_streaming_response.get_documents(
            workspace_ext_id="wrk",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = response.parse()
            assert_matches_type(WorkspaceGetDocumentsResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_documents(self, client: Arbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            client.api.workspace.with_raw_response.get_documents(
                workspace_ext_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_stats(self, client: Arbi) -> None:
        workspace = client.api.workspace.get_stats(
            "wrk",
        )
        assert_matches_type(WorkspaceGetStatsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_stats(self, client: Arbi) -> None:
        response = client.api.workspace.with_raw_response.get_stats(
            "wrk",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = response.parse()
        assert_matches_type(WorkspaceGetStatsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_stats(self, client: Arbi) -> None:
        with client.api.workspace.with_streaming_response.get_stats(
            "wrk",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = response.parse()
            assert_matches_type(WorkspaceGetStatsResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_stats(self, client: Arbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            client.api.workspace.with_raw_response.get_stats(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_tags(self, client: Arbi) -> None:
        workspace = client.api.workspace.get_tags(
            workspace_ext_id="wrk",
        )
        assert_matches_type(WorkspaceGetTagsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_tags_with_all_params(self, client: Arbi) -> None:
        workspace = client.api.workspace.get_tags(
            workspace_ext_id="wrk",
            workspace_key="workspace-key",
        )
        assert_matches_type(WorkspaceGetTagsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_tags(self, client: Arbi) -> None:
        response = client.api.workspace.with_raw_response.get_tags(
            workspace_ext_id="wrk",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = response.parse()
        assert_matches_type(WorkspaceGetTagsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_tags(self, client: Arbi) -> None:
        with client.api.workspace.with_streaming_response.get_tags(
            workspace_ext_id="wrk",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = response.parse()
            assert_matches_type(WorkspaceGetTagsResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_tags(self, client: Arbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            client.api.workspace.with_raw_response.get_tags(
                workspace_ext_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_users(self, client: Arbi) -> None:
        workspace = client.api.workspace.get_users(
            "wrk",
        )
        assert_matches_type(WorkspaceGetUsersResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_users(self, client: Arbi) -> None:
        response = client.api.workspace.with_raw_response.get_users(
            "wrk",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = response.parse()
        assert_matches_type(WorkspaceGetUsersResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_users(self, client: Arbi) -> None:
        with client.api.workspace.with_streaming_response.get_users(
            "wrk",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = response.parse()
            assert_matches_type(WorkspaceGetUsersResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_users(self, client: Arbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            client.api.workspace.with_raw_response.get_users(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_remove_user(self, client: Arbi) -> None:
        workspace = client.api.workspace.remove_user(
            workspace_ext_id="wrk",
            user_ext_id="usr-bFXA5r3A",
        )
        assert_matches_type(WorkspaceRemoveUserResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_remove_user(self, client: Arbi) -> None:
        response = client.api.workspace.with_raw_response.remove_user(
            workspace_ext_id="wrk",
            user_ext_id="usr-bFXA5r3A",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = response.parse()
        assert_matches_type(WorkspaceRemoveUserResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_remove_user(self, client: Arbi) -> None:
        with client.api.workspace.with_streaming_response.remove_user(
            workspace_ext_id="wrk",
            user_ext_id="usr-bFXA5r3A",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = response.parse()
            assert_matches_type(WorkspaceRemoveUserResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_remove_user(self, client: Arbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            client.api.workspace.with_raw_response.remove_user(
                workspace_ext_id="",
                user_ext_id="usr-bFXA5r3A",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_share(self, client: Arbi) -> None:
        workspace = client.api.workspace.share(
            workspace_ext_id="wrk",
            recipient_email="recipient_email",
        )
        assert_matches_type(WorkspaceShareResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_share_with_all_params(self, client: Arbi) -> None:
        workspace = client.api.workspace.share(
            workspace_ext_id="wrk",
            recipient_email="recipient_email",
            workspace_key="workspace-key",
        )
        assert_matches_type(WorkspaceShareResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_share(self, client: Arbi) -> None:
        response = client.api.workspace.with_raw_response.share(
            workspace_ext_id="wrk",
            recipient_email="recipient_email",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = response.parse()
        assert_matches_type(WorkspaceShareResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_share(self, client: Arbi) -> None:
        with client.api.workspace.with_streaming_response.share(
            workspace_ext_id="wrk",
            recipient_email="recipient_email",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = response.parse()
            assert_matches_type(WorkspaceShareResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_share(self, client: Arbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            client.api.workspace.with_raw_response.share(
                workspace_ext_id="",
                recipient_email="recipient_email",
            )


class TestAsyncWorkspace:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.update(
            workspace_ext_id="wrk",
        )
        assert_matches_type(WorkspaceResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.update(
            workspace_ext_id="wrk",
            description="description",
            is_public=True,
            name="name",
            workspace_key="workspace-key",
        )
        assert_matches_type(WorkspaceResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncArbi) -> None:
        response = await async_client.api.workspace.with_raw_response.update(
            workspace_ext_id="wrk",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = await response.parse()
        assert_matches_type(WorkspaceResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncArbi) -> None:
        async with async_client.api.workspace.with_streaming_response.update(
            workspace_ext_id="wrk",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = await response.parse()
            assert_matches_type(WorkspaceResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncArbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            await async_client.api.workspace.with_raw_response.update(
                workspace_ext_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.delete(
            "wrk",
        )
        assert_matches_type(WorkspaceDeleteResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncArbi) -> None:
        response = await async_client.api.workspace.with_raw_response.delete(
            "wrk",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = await response.parse()
        assert_matches_type(WorkspaceDeleteResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncArbi) -> None:
        async with async_client.api.workspace.with_streaming_response.delete(
            "wrk",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = await response.parse()
            assert_matches_type(WorkspaceDeleteResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncArbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            await async_client.api.workspace.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_copy(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.copy(
            workspace_ext_id="wrk",
            items=["string"],
            target_workspace_ext_id="wrk-bFXA5r3A",
        )
        assert_matches_type(WorkspaceCopyResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_copy_with_all_params(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.copy(
            workspace_ext_id="wrk",
            items=["string"],
            target_workspace_ext_id="wrk-bFXA5r3A",
            target_workspace_key="target-workspace-key",
            workspace_key="workspace-key",
        )
        assert_matches_type(WorkspaceCopyResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_copy(self, async_client: AsyncArbi) -> None:
        response = await async_client.api.workspace.with_raw_response.copy(
            workspace_ext_id="wrk",
            items=["string"],
            target_workspace_ext_id="wrk-bFXA5r3A",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = await response.parse()
        assert_matches_type(WorkspaceCopyResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_copy(self, async_client: AsyncArbi) -> None:
        async with async_client.api.workspace.with_streaming_response.copy(
            workspace_ext_id="wrk",
            items=["string"],
            target_workspace_ext_id="wrk-bFXA5r3A",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = await response.parse()
            assert_matches_type(WorkspaceCopyResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_copy(self, async_client: AsyncArbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            await async_client.api.workspace.with_raw_response.copy(
                workspace_ext_id="",
                items=["string"],
                target_workspace_ext_id="wrk-bFXA5r3A",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_protected(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.create_protected(
            name="name",
        )
        assert_matches_type(WorkspaceResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_protected_with_all_params(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.create_protected(
            name="name",
            description="description",
            is_public=True,
        )
        assert_matches_type(WorkspaceResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create_protected(self, async_client: AsyncArbi) -> None:
        response = await async_client.api.workspace.with_raw_response.create_protected(
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = await response.parse()
        assert_matches_type(WorkspaceResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create_protected(self, async_client: AsyncArbi) -> None:
        async with async_client.api.workspace.with_streaming_response.create_protected(
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = await response.parse()
            assert_matches_type(WorkspaceResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_conversations(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.get_conversations(
            "wrk",
        )
        assert_matches_type(WorkspaceGetConversationsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_conversations(self, async_client: AsyncArbi) -> None:
        response = await async_client.api.workspace.with_raw_response.get_conversations(
            "wrk",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = await response.parse()
        assert_matches_type(WorkspaceGetConversationsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_conversations(self, async_client: AsyncArbi) -> None:
        async with async_client.api.workspace.with_streaming_response.get_conversations(
            "wrk",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = await response.parse()
            assert_matches_type(WorkspaceGetConversationsResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_conversations(self, async_client: AsyncArbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            await async_client.api.workspace.with_raw_response.get_conversations(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_documents(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.get_documents(
            workspace_ext_id="wrk",
        )
        assert_matches_type(WorkspaceGetDocumentsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_documents_with_all_params(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.get_documents(
            workspace_ext_id="wrk",
            workspace_key="workspace-key",
        )
        assert_matches_type(WorkspaceGetDocumentsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_documents(self, async_client: AsyncArbi) -> None:
        response = await async_client.api.workspace.with_raw_response.get_documents(
            workspace_ext_id="wrk",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = await response.parse()
        assert_matches_type(WorkspaceGetDocumentsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_documents(self, async_client: AsyncArbi) -> None:
        async with async_client.api.workspace.with_streaming_response.get_documents(
            workspace_ext_id="wrk",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = await response.parse()
            assert_matches_type(WorkspaceGetDocumentsResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_documents(self, async_client: AsyncArbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            await async_client.api.workspace.with_raw_response.get_documents(
                workspace_ext_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_stats(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.get_stats(
            "wrk",
        )
        assert_matches_type(WorkspaceGetStatsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_stats(self, async_client: AsyncArbi) -> None:
        response = await async_client.api.workspace.with_raw_response.get_stats(
            "wrk",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = await response.parse()
        assert_matches_type(WorkspaceGetStatsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_stats(self, async_client: AsyncArbi) -> None:
        async with async_client.api.workspace.with_streaming_response.get_stats(
            "wrk",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = await response.parse()
            assert_matches_type(WorkspaceGetStatsResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_stats(self, async_client: AsyncArbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            await async_client.api.workspace.with_raw_response.get_stats(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_tags(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.get_tags(
            workspace_ext_id="wrk",
        )
        assert_matches_type(WorkspaceGetTagsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_tags_with_all_params(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.get_tags(
            workspace_ext_id="wrk",
            workspace_key="workspace-key",
        )
        assert_matches_type(WorkspaceGetTagsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_tags(self, async_client: AsyncArbi) -> None:
        response = await async_client.api.workspace.with_raw_response.get_tags(
            workspace_ext_id="wrk",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = await response.parse()
        assert_matches_type(WorkspaceGetTagsResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_tags(self, async_client: AsyncArbi) -> None:
        async with async_client.api.workspace.with_streaming_response.get_tags(
            workspace_ext_id="wrk",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = await response.parse()
            assert_matches_type(WorkspaceGetTagsResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_tags(self, async_client: AsyncArbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            await async_client.api.workspace.with_raw_response.get_tags(
                workspace_ext_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_users(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.get_users(
            "wrk",
        )
        assert_matches_type(WorkspaceGetUsersResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_users(self, async_client: AsyncArbi) -> None:
        response = await async_client.api.workspace.with_raw_response.get_users(
            "wrk",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = await response.parse()
        assert_matches_type(WorkspaceGetUsersResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_users(self, async_client: AsyncArbi) -> None:
        async with async_client.api.workspace.with_streaming_response.get_users(
            "wrk",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = await response.parse()
            assert_matches_type(WorkspaceGetUsersResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_users(self, async_client: AsyncArbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            await async_client.api.workspace.with_raw_response.get_users(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_remove_user(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.remove_user(
            workspace_ext_id="wrk",
            user_ext_id="usr-bFXA5r3A",
        )
        assert_matches_type(WorkspaceRemoveUserResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_remove_user(self, async_client: AsyncArbi) -> None:
        response = await async_client.api.workspace.with_raw_response.remove_user(
            workspace_ext_id="wrk",
            user_ext_id="usr-bFXA5r3A",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = await response.parse()
        assert_matches_type(WorkspaceRemoveUserResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_remove_user(self, async_client: AsyncArbi) -> None:
        async with async_client.api.workspace.with_streaming_response.remove_user(
            workspace_ext_id="wrk",
            user_ext_id="usr-bFXA5r3A",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = await response.parse()
            assert_matches_type(WorkspaceRemoveUserResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_remove_user(self, async_client: AsyncArbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            await async_client.api.workspace.with_raw_response.remove_user(
                workspace_ext_id="",
                user_ext_id="usr-bFXA5r3A",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_share(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.share(
            workspace_ext_id="wrk",
            recipient_email="recipient_email",
        )
        assert_matches_type(WorkspaceShareResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_share_with_all_params(self, async_client: AsyncArbi) -> None:
        workspace = await async_client.api.workspace.share(
            workspace_ext_id="wrk",
            recipient_email="recipient_email",
            workspace_key="workspace-key",
        )
        assert_matches_type(WorkspaceShareResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_share(self, async_client: AsyncArbi) -> None:
        response = await async_client.api.workspace.with_raw_response.share(
            workspace_ext_id="wrk",
            recipient_email="recipient_email",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        workspace = await response.parse()
        assert_matches_type(WorkspaceShareResponse, workspace, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_share(self, async_client: AsyncArbi) -> None:
        async with async_client.api.workspace.with_streaming_response.share(
            workspace_ext_id="wrk",
            recipient_email="recipient_email",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            workspace = await response.parse()
            assert_matches_type(WorkspaceShareResponse, workspace, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_share(self, async_client: AsyncArbi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_ext_id` but received ''"):
            await async_client.api.workspace.with_raw_response.share(
                workspace_ext_id="",
                recipient_email="recipient_email",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["RetrieverConfigParam"]


class RetrieverConfigParam(TypedDict, total=False):
    group_size: Annotated[int, PropertyInfo(alias="GROUP_SIZE")]
    """Maximum number of chunks per document for retrieval."""

    max_distinct_documents: Annotated[int, PropertyInfo(alias="MAX_DISTINCT_DOCUMENTS")]
    """Maximum number of distinct documents to search for."""

    max_total_chunks_to_retrieve: Annotated[int, PropertyInfo(alias="MAX_TOTAL_CHUNKS_TO_RETRIEVE")]
    """Maximum total number of chunks to retrieve for all documents retrieved."""

    min_retrieval_sim_score: Annotated[float, PropertyInfo(alias="MIN_RETRIEVAL_SIM_SCORE")]
    """Minimum similarity score for retrieval of a chunk."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .user import (
    UserResource,
    AsyncUserResource,
    UserResourceWithRawResponse,
    AsyncUserResourceWithRawResponse,
    UserResourceWithStreamingResponse,
    AsyncUserResourceWithStreamingResponse,
)
from .contacts import (
    ContactsResource,
    AsyncContactsResource,
    ContactsResourceWithRawResponse,
    AsyncContactsResourceWithRawResponse,
    ContactsResourceWithStreamingResponse,
    AsyncContactsResourceWithStreamingResponse,
)
from .settings import (
    SettingsResource,
    AsyncSettingsResource,
    SettingsResourceWithRawResponse,
    AsyncSettingsResourceWithRawResponse,
    SettingsResourceWithStreamingResponse,
    AsyncSettingsResourceWithStreamingResponse,
)
from .subscription import (
    SubscriptionResource,
    AsyncSubscriptionResource,
    SubscriptionResourceWithRawResponse,
    AsyncSubscriptionResourceWithRawResponse,
    SubscriptionResourceWithStreamingResponse,
    AsyncSubscriptionResourceWithStreamingResponse,
)

__all__ = [
    "SettingsResource",
    "AsyncSettingsResource",
    "SettingsResourceWithRawResponse",
    "AsyncSettingsResourceWithRawResponse",
    "SettingsResourceWithStreamingResponse",
    "AsyncSettingsResourceWithStreamingResponse",
    "SubscriptionResource",
    "AsyncSubscriptionResource",
    "SubscriptionResourceWithRawResponse",
    "AsyncSubscriptionResourceWithRawResponse",
    "SubscriptionResourceWithStreamingResponse",
    "AsyncSubscriptionResourceWithStreamingResponse",
    "ContactsResource",
    "AsyncContactsResource",
    "ContactsResourceWithRawResponse",
    "AsyncContactsResourceWithRawResponse",
    "ContactsResourceWithStreamingResponse",
    "AsyncContactsResourceWithStreamingResponse",
    "UserResource",
    "AsyncUserResource",
    "UserResourceWithRawResponse",
    "AsyncUserResourceWithRawResponse",
    "UserResourceWithStreamingResponse",
    "AsyncUserResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.api.conversation import user_add_params, user_remove_params
from ....types.api.conversation.user_add_response import UserAddResponse
from ....types.api.conversation.user_remove_response import UserRemoveResponse

__all__ = ["UserResource", "AsyncUserResource"]


class UserResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> UserResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#accessing-raw-response-data-eg-headers
        """
        return UserResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> UserResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#with_streaming_response
        """
        return UserResourceWithStreamingResponse(self)

    def add(
        self,
        conversation_ext_id: str,
        *,
        user_ext_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> UserAddResponse:
        """
        Add a user to a conversation.

        RLS ensures the user can only add users to conversations they have access to.
        PostgreSQL constraints handle duplicate users.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not conversation_ext_id:
            raise ValueError(
                f"Expected a non-empty value for `conversation_ext_id` but received {conversation_ext_id!r}"
            )
        return self._post(
            f"/api/conversation/{conversation_ext_id}/user",
            body=maybe_transform({"user_ext_id": user_ext_id}, user_add_params.UserAddParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserAddResponse,
        )

    def remove(
        self,
        conversation_ext_id: str,
        *,
        user_ext_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> UserRemoveResponse:
        """
        Remove a user from a conversation.

        RLS ensures the user can only modify conversations they have access to.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not conversation_ext_id:
            raise ValueError(
                f"Expected a non-empty value for `conversation_ext_id` but received {conversation_ext_id!r}"
            )
        return self._delete(
            f"/api/conversation/{conversation_ext_id}/user",
            body=maybe_transform({"user_ext_id": user_ext_id}, user_remove_params.UserRemoveParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserRemoveResponse,
        )


class AsyncUserResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncUserResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#accessing-raw-response-data-eg-headers
        """
        return AsyncUserResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncUserResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#with_streaming_response
        """
        return AsyncUserResourceWithStreamingResponse(self)

    async def add(
        self,
        conversation_ext_id: str,
        *,
        user_ext_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> UserAddResponse:
        """
        Add a user to a conversation.

        RLS ensures the user can only add users to conversations they have access to.
        PostgreSQL constraints handle duplicate users.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not conversation_ext_id:
            raise ValueError(
                f"Expected a non-empty value for `conversation_ext_id` but received {conversation_ext_id!r}"
            )
        return await self._post(
            f"/api/conversation/{conversation_ext_id}/user",
            body=await async_maybe_transform({"user_ext_id": user_ext_id}, user_add_params.UserAddParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserAddResponse,
        )

    async def remove(
        self,
        conversation_ext_id: str,
        *,
        user_ext_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> UserRemoveResponse:
        """
        Remove a user from a conversation.

        RLS ensures the user can only modify conversations they have access to.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not conversation_ext_id:
            raise ValueError(
                f"Expected a non-empty value for `conversation_ext_id` but received {conversation_ext_id!r}"
            )
        return await self._delete(
            f"/api/conversation/{conversation_ext_id}/user",
            body=await async_maybe_transform({"user_ext_id": user_ext_id}, user_remove_params.UserRemoveParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserRemoveResponse,
        )


class UserResourceWithRawResponse:
    def __init__(self, user: UserResource) -> None:
        self._user = user

        self.add = to_raw_response_wrapper(
            user.add,
        )
        self.remove = to_raw_response_wrapper(
            user.remove,
        )


class AsyncUserResourceWithRawResponse:
    def __init__(self, user: AsyncUserResource) -> None:
        self._user = user

        self.add = async_to_raw_response_wrapper(
            user.add,
        )
        self.remove = async_to_raw_response_wrapper(
            user.remove,
        )


class UserResourceWithStreamingResponse:
    def __init__(self, user: UserResource) -> None:
        self._user = user

        self.add = to_streamed_response_wrapper(
            user.add,
        )
        self.remove = to_streamed_response_wrapper(
            user.remove,
        )


class AsyncUserResourceWithStreamingResponse:
    def __init__(self, user: AsyncUserResource) -> None:
        self._user = user

        self.add = async_to_streamed_response_wrapper(
            user.add,
        )
        self.remove = async_to_streamed_response_wrapper(
            user.remove,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .doc_response import DocResponse

__all__ = ["DocumentUpdateResponse"]

DocumentUpdateResponse: TypeAlias = List[DocResponse]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional
from datetime import datetime
from typing_extensions import Literal, Annotated, TypeAlias

from ..chunk import Chunk
from ..._utils import PropertyInfo
from ..._models import BaseModel

__all__ = [
    "ConversationRetrieveMessageResponse",
    "Tools",
    "ToolsModelCitationTool",
    "ToolsModelCitationToolToolResponses",
    "ToolsRetrievalChunkToolOutput",
    "ToolsRetrievalFullContextToolOutput",
    "ToolsTraceTool",
]


class ToolsModelCitationToolToolResponses(BaseModel):
    """Data for a single citation"""

    chunk_ids: List[str]

    offset_end: int

    offset_start: int

    statement: str


class ToolsModelCitationTool(BaseModel):
    description: Optional[str] = None

    name: Optional[Literal["model_citation"]] = None

    tool_responses: Optional[Dict[str, ToolsModelCitationToolToolResponses]] = None


class ToolsRetrievalChunkToolOutput(BaseModel):
    description: Optional[str] = None

    name: Optional[Literal["retrieval_chunk"]] = None

    tool_args: Optional[Dict[str, List[str]]] = None

    tool_responses: Optional[Dict[str, List[Chunk]]] = None


class ToolsRetrievalFullContextToolOutput(BaseModel):
    description: Optional[str] = None

    name: Optional[Literal["retrieval_full_context"]] = None

    tool_args: Optional[Dict[str, object]] = None

    tool_responses: Optional[Dict[str, List[Chunk]]] = None


class ToolsTraceTool(BaseModel):
    """Execution trace tool that captures the full execution history of a request."""

    description: Optional[str] = None

    duration_seconds: Optional[float] = None

    name: Optional[Literal["trace"]] = None

    start_time: Optional[float] = None

    steps: Optional[List[Dict[str, object]]] = None

    trace_id: Optional[str] = None


Tools: TypeAlias = Annotated[
    Union[ToolsModelCitationTool, ToolsRetrievalChunkToolOutput, ToolsRetrievalFullContextToolOutput, ToolsTraceTool],
    PropertyInfo(discriminator="name"),
]


class ConversationRetrieveMessageResponse(BaseModel):
    """DTO for API responses to frontend - all fields guaranteed to be present"""

    content: str

    conversation_ext_id: str

    created_at: datetime

    created_by_ext_id: str

    external_id: str

    role: Literal["user", "assistant", "system"]

    config_ext_id: Optional[str] = None

    parent_message_ext_id: Optional[str] = None

    shared: Optional[bool] = None

    tools: Optional[Dict[str, Tools]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["DoctagUpdateParams"]


class DoctagUpdateParams(TypedDict, total=False):
    doc_ext_id: Required[str]

    tag_ext_id: Required[str]

    note: Optional[str]

    workspace_key: Annotated[str, PropertyInfo(alias="workspace-key")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ... import _resource
from .tag import (
    TagResource,
    AsyncTagResource,
    TagResourceWithRawResponse,
    AsyncTagResourceWithRawResponse,
    TagResourceWithStreamingResponse,
    AsyncTagResourceWithStreamingResponse,
)
from .health import (
    HealthResource,
    AsyncHealthResource,
    HealthResourceWithRawResponse,
    AsyncHealthResourceWithRawResponse,
    HealthResourceWithStreamingResponse,
    AsyncHealthResourceWithStreamingResponse,
)
from .configs import (
    ConfigsResource,
    AsyncConfigsResource,
    ConfigsResourceWithRawResponse,
    AsyncConfigsResourceWithRawResponse,
    ConfigsResourceWithStreamingResponse,
    AsyncConfigsResourceWithStreamingResponse,
)
from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._compat import cached_property
from .assistant import (
    AssistantResource,
    AsyncAssistantResource,
    AssistantResourceWithRawResponse,
    AsyncAssistantResourceWithRawResponse,
    AssistantResourceWithStreamingResponse,
    AsyncAssistantResourceWithStreamingResponse,
)
from .user.user import (
    UserResource,
    AsyncUserResource,
    UserResourceWithRawResponse,
    AsyncUserResourceWithRawResponse,
    UserResourceWithStreamingResponse,
    AsyncUserResourceWithStreamingResponse,
)
from .workspace import (
    WorkspaceResource,
    AsyncWorkspaceResource,
    WorkspaceResourceWithRawResponse,
    AsyncWorkspaceResourceWithRawResponse,
    WorkspaceResourceWithStreamingResponse,
    AsyncWorkspaceResourceWithStreamingResponse,
)
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .notifications import (
    NotificationsResource,
    AsyncNotificationsResource,
    NotificationsResourceWithRawResponse,
    AsyncNotificationsResourceWithRawResponse,
    NotificationsResourceWithStreamingResponse,
    AsyncNotificationsResourceWithStreamingResponse,
)
from ..._base_client import make_request_options
from .document.document import (
    DocumentResource,
    AsyncDocumentResource,
    DocumentResourceWithRawResponse,
    AsyncDocumentResourceWithRawResponse,
    DocumentResourceWithStreamingResponse,
    AsyncDocumentResourceWithStreamingResponse,
)
from .conversation.conversation import (
    ConversationResource,
    AsyncConversationResource,
    ConversationResourceWithRawResponse,
    AsyncConversationResourceWithRawResponse,
    ConversationResourceWithStreamingResponse,
    AsyncConversationResourceWithStreamingResponse,
)

__all__ = ["APIResource", "AsyncAPIResource"]


class APIResource(_resource.SyncAPIResource):
    @cached_property
    def user(self) -> UserResource:
        return UserResource(self._client)

    @cached_property
    def workspace(self) -> WorkspaceResource:
        return WorkspaceResource(self._client)

    @cached_property
    def document(self) -> DocumentResource:
        return DocumentResource(self._client)

    @cached_property
    def conversation(self) -> ConversationResource:
        return ConversationResource(self._client)

    @cached_property
    def assistant(self) -> AssistantResource:
        return AssistantResource(self._client)

    @cached_property
    def health(self) -> HealthResource:
        return HealthResource(self._client)

    @cached_property
    def tag(self) -> TagResource:
        return TagResource(self._client)

    @cached_property
    def configs(self) -> ConfigsResource:
        return ConfigsResource(self._client)

    @cached_property
    def notifications(self) -> NotificationsResource:
        return NotificationsResource(self._client)

    @cached_property
    def with_raw_response(self) -> APIResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#accessing-raw-response-data-eg-headers
        """
        return APIResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> APIResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#with_streaming_response
        """
        return APIResourceWithStreamingResponse(self)

    def index(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """Serves the admin application page with necessary configuration variables."""
        return self._get(
            "/api",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncAPIResource(_resource.AsyncAPIResource):
    @cached_property
    def user(self) -> AsyncUserResource:
        return AsyncUserResource(self._client)

    @cached_property
    def workspace(self) -> AsyncWorkspaceResource:
        return AsyncWorkspaceResource(self._client)

    @cached_property
    def document(self) -> AsyncDocumentResource:
        return AsyncDocumentResource(self._client)

    @cached_property
    def conversation(self) -> AsyncConversationResource:
        return AsyncConversationResource(self._client)

    @cached_property
    def assistant(self) -> AsyncAssistantResource:
        return AsyncAssistantResource(self._client)

    @cached_property
    def health(self) -> AsyncHealthResource:
        return AsyncHealthResource(self._client)

    @cached_property
    def tag(self) -> AsyncTagResource:
        return AsyncTagResource(self._client)

    @cached_property
    def configs(self) -> AsyncConfigsResource:
        return AsyncConfigsResource(self._client)

    @cached_property
    def notifications(self) -> AsyncNotificationsResource:
        return AsyncNotificationsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncAPIResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAPIResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAPIResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#with_streaming_response
        """
        return AsyncAPIResourceWithStreamingResponse(self)

    async def index(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """Serves the admin application page with necessary configuration variables."""
        return await self._get(
            "/api",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class APIResourceWithRawResponse:
    def __init__(self, api: APIResource) -> None:
        self._api = api

        self.index = to_raw_response_wrapper(
            api.index,
        )

    @cached_property
    def user(self) -> UserResourceWithRawResponse:
        return UserResourceWithRawResponse(self._api.user)

    @cached_property
    def workspace(self) -> WorkspaceResourceWithRawResponse:
        return WorkspaceResourceWithRawResponse(self._api.workspace)

    @cached_property
    def document(self) -> DocumentResourceWithRawResponse:
        return DocumentResourceWithRawResponse(self._api.document)

    @cached_property
    def conversation(self) -> ConversationResourceWithRawResponse:
        return ConversationResourceWithRawResponse(self._api.conversation)

    @cached_property
    def assistant(self) -> AssistantResourceWithRawResponse:
        return AssistantResourceWithRawResponse(self._api.assistant)

    @cached_property
    def health(self) -> HealthResourceWithRawResponse:
        return HealthResourceWithRawResponse(self._api.health)

    @cached_property
    def tag(self) -> TagResourceWithRawResponse:
        return TagResourceWithRawResponse(self._api.tag)

    @cached_property
    def configs(self) -> ConfigsResourceWithRawResponse:
        return ConfigsResourceWithRawResponse(self._api.configs)

    @cached_property
    def notifications(self) -> NotificationsResourceWithRawResponse:
        return NotificationsResourceWithRawResponse(self._api.notifications)


class AsyncAPIResourceWithRawResponse:
    def __init__(self, api: AsyncAPIResource) -> None:
        self._api = api

        self.index = async_to_raw_response_wrapper(
            api.index,
        )

    @cached_property
    def user(self) -> AsyncUserResourceWithRawResponse:
        return AsyncUserResourceWithRawResponse(self._api.user)

    @cached_property
    def workspace(self) -> AsyncWorkspaceResourceWithRawResponse:
        return AsyncWorkspaceResourceWithRawResponse(self._api.workspace)

    @cached_property
    def document(self) -> AsyncDocumentResourceWithRawResponse:
        return AsyncDocumentResourceWithRawResponse(self._api.document)

    @cached_property
    def conversation(self) -> AsyncConversationResourceWithRawResponse:
        return AsyncConversationResourceWithRawResponse(self._api.conversation)

    @cached_property
    def assistant(self) -> AsyncAssistantResourceWithRawResponse:
        return AsyncAssistantResourceWithRawResponse(self._api.assistant)

    @cached_property
    def health(self) -> AsyncHealthResourceWithRawResponse:
        return AsyncHealthResourceWithRawResponse(self._api.health)

    @cached_property
    def tag(self) -> AsyncTagResourceWithRawResponse:
        return AsyncTagResourceWithRawResponse(self._api.tag)

    @cached_property
    def configs(self) -> AsyncConfigsResourceWithRawResponse:
        return AsyncConfigsResourceWithRawResponse(self._api.configs)

    @cached_property
    def notifications(self) -> AsyncNotificationsResourceWithRawResponse:
        return AsyncNotificationsResourceWithRawResponse(self._api.notifications)


class APIResourceWithStreamingResponse:
    def __init__(self, api: APIResource) -> None:
        self._api = api

        self.index = to_streamed_response_wrapper(
            api.index,
        )

    @cached_property
    def user(self) -> UserResourceWithStreamingResponse:
        return UserResourceWithStreamingResponse(self._api.user)

    @cached_property
    def workspace(self) -> WorkspaceResourceWithStreamingResponse:
        return WorkspaceResourceWithStreamingResponse(self._api.workspace)

    @cached_property
    def document(self) -> DocumentResourceWithStreamingResponse:
        return DocumentResourceWithStreamingResponse(self._api.document)

    @cached_property
    def conversation(self) -> ConversationResourceWithStreamingResponse:
        return ConversationResourceWithStreamingResponse(self._api.conversation)

    @cached_property
    def assistant(self) -> AssistantResourceWithStreamingResponse:
        return AssistantResourceWithStreamingResponse(self._api.assistant)

    @cached_property
    def health(self) -> HealthResourceWithStreamingResponse:
        return HealthResourceWithStreamingResponse(self._api.health)

    @cached_property
    def tag(self) -> TagResourceWithStreamingResponse:
        return TagResourceWithStreamingResponse(self._api.tag)

    @cached_property
    def configs(self) -> ConfigsResourceWithStreamingResponse:
        return ConfigsResourceWithStreamingResponse(self._api.configs)

    @cached_property
    def notifications(self) -> NotificationsResourceWithStreamingResponse:
        return NotificationsResourceWithStreamingResponse(self._api.notifications)


class AsyncAPIResourceWithStreamingResponse:
    def __init__(self, api: AsyncAPIResource) -> None:
        self._api = api

        self.index = async_to_streamed_response_wrapper(
            api.index,
        )

    @cached_property
    def user(self) -> AsyncUserResourceWithStreamingResponse:
        return AsyncUserResourceWithStreamingResponse(self._api.user)

    @cached_property
    def workspace(self) -> AsyncWorkspaceResourceWithStreamingResponse:
        return AsyncWorkspaceResourceWithStreamingResponse(self._api.workspace)

    @cached_property
    def document(self) -> AsyncDocumentResourceWithStreamingResponse:
        return AsyncDocumentResourceWithStreamingResponse(self._api.document)

    @cached_property
    def conversation(self) -> AsyncConversationResourceWithStreamingResponse:
        return AsyncConversationResourceWithStreamingResponse(self._api.conversation)

    @cached_property
    def assistant(self) -> AsyncAssistantResourceWithStreamingResponse:
        return AsyncAssistantResourceWithStreamingResponse(self._api.assistant)

    @cached_property
    def health(self) -> AsyncHealthResourceWithStreamingResponse:
        return AsyncHealthResourceWithStreamingResponse(self._api.health)

    @cached_property
    def tag(self) -> AsyncTagResourceWithStreamingResponse:
        return AsyncTagResourceWithStreamingResponse(self._api.tag)

    @cached_property
    def configs(self) -> AsyncConfigsResourceWithStreamingResponse:
        return AsyncConfigsResourceWithStreamingResponse(self._api.configs)

    @cached_property
    def notifications(self) -> AsyncNotificationsResourceWithStreamingResponse:
        return AsyncNotificationsResourceWithStreamingResponse(self._api.notifications)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal, TypeAlias

from ...._models import BaseModel

__all__ = ["ContactCreateResponse", "ContactCreateResponseItem"]


class ContactCreateResponseItem(BaseModel):
    """Response model for contact records.

    Matches WorkspaceUserResponse structure for consistency.
    """

    created_at: str

    email: str

    external_id: str

    status: Literal["invitation_pending", "invitation_expired", "invitation_accepted", "existing_user"]

    last_name: Optional[str] = None

    name: Optional[str] = None

    user_ext_id: Optional[str] = None


ContactCreateResponse: TypeAlias = List[ContactCreateResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["UserRemoveParams"]


class UserRemoveParams(TypedDict, total=False):
    user_ext_id: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel
from .chunk_metadata import ChunkMetadata

__all__ = ["Chunk"]


class Chunk(BaseModel):
    content: str

    metadata: ChunkMetadata



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from .chunk_metadata_param import ChunkMetadataParam

__all__ = ["ChunkParam"]


class ChunkParam(TypedDict, total=False):
    content: Required[str]

    metadata: Required[ChunkMetadataParam]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["NotificationGetSchemasResponse"]


class NotificationGetSchemasResponse(BaseModel):
    """Response containing JSON schemas for all WebSocket message types."""

    auth_result_message: Dict[str, object] = FieldInfo(alias="AuthResultMessage")

    connection_closed_message: Dict[str, object] = FieldInfo(alias="ConnectionClosedMessage")

    contact_accepted_message: Dict[str, object] = FieldInfo(alias="ContactAcceptedMessage")

    notification_message: Dict[str, object] = FieldInfo(alias="NotificationMessage")

    pong_message: Dict[str, object] = FieldInfo(alias="PongMessage")

    task_update_message: Dict[str, object] = FieldInfo(alias="TaskUpdateMessage")

    workspace_share_message: Dict[str, object] = FieldInfo(alias="WorkspaceShareMessage")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from ..._types import FileTypes, SequenceNotStr
from ..._utils import PropertyInfo

__all__ = ["DocumentUploadParams"]


class DocumentUploadParams(TypedDict, total=False):
    workspace_ext_id: Required[str]

    files: Required[SequenceNotStr[FileTypes]]
    """Multiple files to upload"""

    config_ext_id: Optional[str]
    """Configuration to use for processing"""

    shared: bool
    """Whether the document should be shared with workspace members"""

    workspace_key: Annotated[str, PropertyInfo(alias="workspace-key")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NoneType, NotGiven, SequenceNotStr, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.api.user import contact_create_params, contact_delete_params
from ....types.api.user.contact_list_response import ContactListResponse
from ....types.api.user.contact_create_response import ContactCreateResponse

__all__ = ["ContactsResource", "AsyncContactsResource"]


class ContactsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ContactsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#accessing-raw-response-data-eg-headers
        """
        return ContactsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ContactsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#with_streaming_response
        """
        return ContactsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        emails: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ContactCreateResponse:
        """
        Add multiple contacts by email addresses.

        For each email:

        - If user already exists: Adds them to contacts with status="registered"
        - If user doesn't exist: Sends invitation email and creates contact with
          status="invited"

        Protected endpoint - requires authentication. Returns list of created contact
        records.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api/user/contacts",
            body=maybe_transform({"emails": emails}, contact_create_params.ContactCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ContactCreateResponse,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ContactListResponse:
        """Get all contacts created by the current user.

        Uses RLS to enforce that users can
        only see their own contacts. Includes registered user info when available.
        """
        return self._get(
            "/api/user/contacts",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ContactListResponse,
        )

    def delete(
        self,
        *,
        contact_ids: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Delete specific contacts by their external IDs.

        Users can only delete their own
        contacts (enforced by RLS).

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            "/api/user/contacts",
            body=maybe_transform({"contact_ids": contact_ids}, contact_delete_params.ContactDeleteParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncContactsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncContactsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#accessing-raw-response-data-eg-headers
        """
        return AsyncContactsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncContactsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#with_streaming_response
        """
        return AsyncContactsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        emails: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ContactCreateResponse:
        """
        Add multiple contacts by email addresses.

        For each email:

        - If user already exists: Adds them to contacts with status="registered"
        - If user doesn't exist: Sends invitation email and creates contact with
          status="invited"

        Protected endpoint - requires authentication. Returns list of created contact
        records.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api/user/contacts",
            body=await async_maybe_transform({"emails": emails}, contact_create_params.ContactCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ContactCreateResponse,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ContactListResponse:
        """Get all contacts created by the current user.

        Uses RLS to enforce that users can
        only see their own contacts. Includes registered user info when available.
        """
        return await self._get(
            "/api/user/contacts",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ContactListResponse,
        )

    async def delete(
        self,
        *,
        contact_ids: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Delete specific contacts by their external IDs.

        Users can only delete their own
        contacts (enforced by RLS).

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            "/api/user/contacts",
            body=await async_maybe_transform({"contact_ids": contact_ids}, contact_delete_params.ContactDeleteParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class ContactsResourceWithRawResponse:
    def __init__(self, contacts: ContactsResource) -> None:
        self._contacts = contacts

        self.create = to_raw_response_wrapper(
            contacts.create,
        )
        self.list = to_raw_response_wrapper(
            contacts.list,
        )
        self.delete = to_raw_response_wrapper(
            contacts.delete,
        )


class AsyncContactsResourceWithRawResponse:
    def __init__(self, contacts: AsyncContactsResource) -> None:
        self._contacts = contacts

        self.create = async_to_raw_response_wrapper(
            contacts.create,
        )
        self.list = async_to_raw_response_wrapper(
            contacts.list,
        )
        self.delete = async_to_raw_response_wrapper(
            contacts.delete,
        )


class ContactsResourceWithStreamingResponse:
    def __init__(self, contacts: ContactsResource) -> None:
        self._contacts = contacts

        self.create = to_streamed_response_wrapper(
            contacts.create,
        )
        self.list = to_streamed_response_wrapper(
            contacts.list,
        )
        self.delete = to_streamed_response_wrapper(
            contacts.delete,
        )


class AsyncContactsResourceWithStreamingResponse:
    def __init__(self, contacts: AsyncContactsResource) -> None:
        self._contacts = contacts

        self.create = async_to_streamed_response_wrapper(
            contacts.create,
        )
        self.list = async_to_streamed_response_wrapper(
            contacts.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            contacts.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, strip_not_given, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.api import tag_create_params, tag_update_params
from ..._base_client import make_request_options
from ...types.api.tag_create_response import TagCreateResponse
from ...types.api.tag_delete_response import TagDeleteResponse
from ...types.api.tag_update_response import TagUpdateResponse

__all__ = ["TagResource", "AsyncTagResource"]


class TagResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TagResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#accessing-raw-response-data-eg-headers
        """
        return TagResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TagResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#with_streaming_response
        """
        return TagResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        name: str,
        workspace_ext_id: str,
        parent_ext_id: Optional[str] | Omit = omit,
        shared: Optional[bool] | Omit = omit,
        tag_type: tag_create_params.TagType | Omit = omit,
        workspace_key: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TagCreateResponse:
        """
        Create a new tag for a given workspace.

        If 'shared' is provided, the tag will be set to shared or private accordingly.
        If 'shared' is not provided, it defaults to True (shared).

        Args:
          tag_type: Tag format configuration stored as JSONB.

              Type-specific fields:

              - select: options (list of choices, can be single or multi-select)
              - checkbox, text, number, folder: type only

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"workspace-key": workspace_key}), **(extra_headers or {})}
        return self._post(
            "/api/tag",
            body=maybe_transform(
                {
                    "name": name,
                    "workspace_ext_id": workspace_ext_id,
                    "parent_ext_id": parent_ext_id,
                    "shared": shared,
                    "tag_type": tag_type,
                },
                tag_create_params.TagCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagCreateResponse,
        )

    def update(
        self,
        tag_ext_id: str,
        *,
        name: Optional[str] | Omit = omit,
        parent_ext_id: Optional[str] | Omit = omit,
        shared: Optional[bool] | Omit = omit,
        workspace_key: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TagUpdateResponse:
        """
        Update a tag by its external ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not tag_ext_id:
            raise ValueError(f"Expected a non-empty value for `tag_ext_id` but received {tag_ext_id!r}")
        extra_headers = {**strip_not_given({"workspace-key": workspace_key}), **(extra_headers or {})}
        return self._patch(
            f"/api/tag/{tag_ext_id}",
            body=maybe_transform(
                {
                    "name": name,
                    "parent_ext_id": parent_ext_id,
                    "shared": shared,
                },
                tag_update_params.TagUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagUpdateResponse,
        )

    def delete(
        self,
        tag_ext_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TagDeleteResponse:
        """
        Delete a tag by its external ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not tag_ext_id:
            raise ValueError(f"Expected a non-empty value for `tag_ext_id` but received {tag_ext_id!r}")
        return self._delete(
            f"/api/tag/{tag_ext_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagDeleteResponse,
        )


class AsyncTagResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTagResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTagResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTagResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#with_streaming_response
        """
        return AsyncTagResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        name: str,
        workspace_ext_id: str,
        parent_ext_id: Optional[str] | Omit = omit,
        shared: Optional[bool] | Omit = omit,
        tag_type: tag_create_params.TagType | Omit = omit,
        workspace_key: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TagCreateResponse:
        """
        Create a new tag for a given workspace.

        If 'shared' is provided, the tag will be set to shared or private accordingly.
        If 'shared' is not provided, it defaults to True (shared).

        Args:
          tag_type: Tag format configuration stored as JSONB.

              Type-specific fields:

              - select: options (list of choices, can be single or multi-select)
              - checkbox, text, number, folder: type only

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"workspace-key": workspace_key}), **(extra_headers or {})}
        return await self._post(
            "/api/tag",
            body=await async_maybe_transform(
                {
                    "name": name,
                    "workspace_ext_id": workspace_ext_id,
                    "parent_ext_id": parent_ext_id,
                    "shared": shared,
                    "tag_type": tag_type,
                },
                tag_create_params.TagCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagCreateResponse,
        )

    async def update(
        self,
        tag_ext_id: str,
        *,
        name: Optional[str] | Omit = omit,
        parent_ext_id: Optional[str] | Omit = omit,
        shared: Optional[bool] | Omit = omit,
        workspace_key: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TagUpdateResponse:
        """
        Update a tag by its external ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not tag_ext_id:
            raise ValueError(f"Expected a non-empty value for `tag_ext_id` but received {tag_ext_id!r}")
        extra_headers = {**strip_not_given({"workspace-key": workspace_key}), **(extra_headers or {})}
        return await self._patch(
            f"/api/tag/{tag_ext_id}",
            body=await async_maybe_transform(
                {
                    "name": name,
                    "parent_ext_id": parent_ext_id,
                    "shared": shared,
                },
                tag_update_params.TagUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagUpdateResponse,
        )

    async def delete(
        self,
        tag_ext_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TagDeleteResponse:
        """
        Delete a tag by its external ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not tag_ext_id:
            raise ValueError(f"Expected a non-empty value for `tag_ext_id` but received {tag_ext_id!r}")
        return await self._delete(
            f"/api/tag/{tag_ext_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagDeleteResponse,
        )


class TagResourceWithRawResponse:
    def __init__(self, tag: TagResource) -> None:
        self._tag = tag

        self.create = to_raw_response_wrapper(
            tag.create,
        )
        self.update = to_raw_response_wrapper(
            tag.update,
        )
        self.delete = to_raw_response_wrapper(
            tag.delete,
        )


class AsyncTagResourceWithRawResponse:
    def __init__(self, tag: AsyncTagResource) -> None:
        self._tag = tag

        self.create = async_to_raw_response_wrapper(
            tag.create,
        )
        self.update = async_to_raw_response_wrapper(
            tag.update,
        )
        self.delete = async_to_raw_response_wrapper(
            tag.delete,
        )


class TagResourceWithStreamingResponse:
    def __init__(self, tag: TagResource) -> None:
        self._tag = tag

        self.create = to_streamed_response_wrapper(
            tag.create,
        )
        self.update = to_streamed_response_wrapper(
            tag.update,
        )
        self.delete = to_streamed_response_wrapper(
            tag.delete,
        )


class AsyncTagResourceWithStreamingResponse:
    def __init__(self, tag: AsyncTagResource) -> None:
        self._tag = tag

        self.create = async_to_streamed_response_wrapper(
            tag.create,
        )
        self.update = async_to_streamed_response_wrapper(
            tag.update,
        )
        self.delete = async_to_streamed_response_wrapper(
            tag.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["WorkspaceShareResponse", "Notifications"]


class Notifications(BaseModel):
    recipient: str

    sender: str


class WorkspaceShareResponse(BaseModel):
    detail: str

    notifications: Notifications

    shared_with: str

    workspace_ext_id: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["RetrieverConfig"]


class RetrieverConfig(BaseModel):
    group_size: Optional[int] = FieldInfo(alias="GROUP_SIZE", default=None)
    """Maximum number of chunks per document for retrieval."""

    max_distinct_documents: Optional[int] = FieldInfo(alias="MAX_DISTINCT_DOCUMENTS", default=None)
    """Maximum number of distinct documents to search for."""

    max_total_chunks_to_retrieve: Optional[int] = FieldInfo(alias="MAX_TOTAL_CHUNKS_TO_RETRIEVE", default=None)
    """Maximum total number of chunks to retrieve for all documents retrieved."""

    min_retrieval_sim_score: Optional[float] = FieldInfo(alias="MIN_RETRIEVAL_SIM_SCORE", default=None)
    """Minimum similarity score for retrieval of a chunk."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["TagCreateResponse", "TagType"]


class TagType(BaseModel):
    """Tag format configuration stored as JSONB.

    Type-specific fields:
    - select: options (list of choices, can be single or multi-select)
    - checkbox, text, number, folder: type only
    """

    options: Optional[List[str]] = None

    type: Optional[Literal["checkbox", "text", "number", "select", "folder"]] = None


class TagCreateResponse(BaseModel):
    created_at: datetime

    created_by_ext_id: str

    doctag_count: int

    external_id: str

    name: str

    shared: bool

    tag_type: TagType
    """Tag format configuration stored as JSONB.

    Type-specific fields:

    - select: options (list of choices, can be single or multi-select)
    - checkbox, text, number, folder: type only
    """

    updated_at: datetime

    workspace_ext_id: str

    parent_ext_id: Optional[str] = None

    updated_by_ext_id: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ...._utils import maybe_transform, strip_not_given, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.api.user import subscription_create_params
from ....types.api.user.subscription_create_response import SubscriptionCreateResponse
from ....types.api.user.subscription_retrieve_response import SubscriptionRetrieveResponse

__all__ = ["SubscriptionResource", "AsyncSubscriptionResource"]


class SubscriptionResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SubscriptionResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#accessing-raw-response-data-eg-headers
        """
        return SubscriptionResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SubscriptionResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#with_streaming_response
        """
        return SubscriptionResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        price_id: str,
        origin: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SubscriptionCreateResponse:
        """
        Create a new Stripe checkout session for subscription purchase.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"origin": origin}), **(extra_headers or {})}
        return self._post(
            "/api/user/subscription",
            body=maybe_transform({"price_id": price_id}, subscription_create_params.SubscriptionCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SubscriptionCreateResponse,
        )

    def retrieve(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SubscriptionRetrieveResponse:
        """
        Get subscription details including Stripe portal URL for management.

        Also updates subscription status based on current Stripe entitlements. This
        ensures status is refreshed after successful payment.
        """
        return self._get(
            "/api/user/subscription",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SubscriptionRetrieveResponse,
        )


class AsyncSubscriptionResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSubscriptionResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSubscriptionResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSubscriptionResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#with_streaming_response
        """
        return AsyncSubscriptionResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        price_id: str,
        origin: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SubscriptionCreateResponse:
        """
        Create a new Stripe checkout session for subscription purchase.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"origin": origin}), **(extra_headers or {})}
        return await self._post(
            "/api/user/subscription",
            body=await async_maybe_transform(
                {"price_id": price_id}, subscription_create_params.SubscriptionCreateParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SubscriptionCreateResponse,
        )

    async def retrieve(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SubscriptionRetrieveResponse:
        """
        Get subscription details including Stripe portal URL for management.

        Also updates subscription status based on current Stripe entitlements. This
        ensures status is refreshed after successful payment.
        """
        return await self._get(
            "/api/user/subscription",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SubscriptionRetrieveResponse,
        )


class SubscriptionResourceWithRawResponse:
    def __init__(self, subscription: SubscriptionResource) -> None:
        self._subscription = subscription

        self.create = to_raw_response_wrapper(
            subscription.create,
        )
        self.retrieve = to_raw_response_wrapper(
            subscription.retrieve,
        )


class AsyncSubscriptionResourceWithRawResponse:
    def __init__(self, subscription: AsyncSubscriptionResource) -> None:
        self._subscription = subscription

        self.create = async_to_raw_response_wrapper(
            subscription.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            subscription.retrieve,
        )


class SubscriptionResourceWithStreamingResponse:
    def __init__(self, subscription: SubscriptionResource) -> None:
        self._subscription = subscription

        self.create = to_streamed_response_wrapper(
            subscription.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            subscription.retrieve,
        )


class AsyncSubscriptionResourceWithStreamingResponse:
    def __init__(self, subscription: AsyncSubscriptionResource) -> None:
        self._subscription = subscription

        self.create = async_to_streamed_response_wrapper(
            subscription.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            subscription.retrieve,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["ChunkMetadataParam"]


class ChunkMetadataParam(TypedDict, total=False):
    chunk_doc_idx: Required[int]

    chunk_ext_id: Required[str]

    chunk_pg_idx: Required[int]

    created_at: Required[str]

    page_number: Required[int]

    chunk_id: Optional[str]

    doc_ext_id: Optional[str]

    doc_title: Optional[str]

    rerank_score: Optional[float]

    score: Optional[float]

    tokens: Optional[int]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .contact_create_params import ContactCreateParams as ContactCreateParams
from .contact_delete_params import ContactDeleteParams as ContactDeleteParams
from .contact_list_response import ContactListResponse as ContactListResponse
from .setting_update_params import SettingUpdateParams as SettingUpdateParams
from .contact_create_response import ContactCreateResponse as ContactCreateResponse
from .setting_retrieve_response import SettingRetrieveResponse as SettingRetrieveResponse
from .subscription_create_params import SubscriptionCreateParams as SubscriptionCreateParams
from .subscription_create_response import SubscriptionCreateResponse as SubscriptionCreateResponse
from .subscription_retrieve_response import SubscriptionRetrieveResponse as SubscriptionRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Any, Optional, cast

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.api import (
    config_create_params,
)
from ..._base_client import make_request_options
from ...types.api.parser_config_param import ParserConfigParam
from ...types.api.chunker_config_param import ChunkerConfigParam
from ...types.api.embedder_config_param import EmbedderConfigParam
from ...types.api.reranker_config_param import RerankerConfigParam
from ...types.api.config_create_response import ConfigCreateResponse
from ...types.api.config_delete_response import ConfigDeleteResponse
from ...types.api.query_llm_config_param import QueryLlmConfigParam
from ...types.api.retriever_config_param import RetrieverConfigParam
from ...types.api.title_llm_config_param import TitleLlmConfigParam
from ...types.api.config_retrieve_response import ConfigRetrieveResponse
from ...types.api.model_citation_config_param import ModelCitationConfigParam
from ...types.api.config_get_versions_response import ConfigGetVersionsResponse
from ...types.api.document_date_extractor_llm_config_param import DocumentDateExtractorLlmConfigParam

__all__ = ["ConfigsResource", "AsyncConfigsResource"]


class ConfigsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ConfigsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#accessing-raw-response-data-eg-headers
        """
        return ConfigsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ConfigsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#with_streaming_response
        """
        return ConfigsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        agent_llm: Optional[config_create_params.AgentLlm] | Omit = omit,
        agents: Optional[config_create_params.Agents] | Omit = omit,
        chunker: Optional[ChunkerConfigParam] | Omit = omit,
        document_date_extractor_llm: Optional[DocumentDateExtractorLlmConfigParam] | Omit = omit,
        embedder: Optional[EmbedderConfigParam] | Omit = omit,
        model_citation: Optional[ModelCitationConfigParam] | Omit = omit,
        parent_message_ext_id: Optional[str] | Omit = omit,
        parser: Optional[ParserConfigParam] | Omit = omit,
        query_llm: Optional[QueryLlmConfigParam] | Omit = omit,
        reranker: Optional[RerankerConfigParam] | Omit = omit,
        retriever: Optional[RetrieverConfigParam] | Omit = omit,
        title: str | Omit = omit,
        title_llm: Optional[TitleLlmConfigParam] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ConfigCreateResponse:
        """
        Save a new configuration.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api/configs/",
            body=maybe_transform(
                {
                    "agent_llm": agent_llm,
                    "agents": agents,
                    "chunker": chunker,
                    "document_date_extractor_llm": document_date_extractor_llm,
                    "embedder": embedder,
                    "model_citation": model_citation,
                    "parent_message_ext_id": parent_message_ext_id,
                    "parser": parser,
                    "query_llm": query_llm,
                    "reranker": reranker,
                    "retriever": retriever,
                    "title": title,
                    "title_llm": title_llm,
                },
                config_create_params.ConfigCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConfigCreateResponse,
        )

    def retrieve(
        self,
        config_ext_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ConfigRetrieveResponse:
        """
        Read configurations from database to be displayed in the UI

        Args:
          config_ext_id: Config name: 'cfg-XXXXXXXX' or 'default' for system default

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not config_ext_id:
            raise ValueError(f"Expected a non-empty value for `config_ext_id` but received {config_ext_id!r}")
        return cast(
            ConfigRetrieveResponse,
            self._get(
                f"/api/configs/{config_ext_id}",
                options=make_request_options(
                    extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
                ),
                cast_to=cast(
                    Any, ConfigRetrieveResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )

    def delete(
        self,
        config_ext_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ConfigDeleteResponse:
        """
        Delete a specific configuration from database

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not config_ext_id:
            raise ValueError(f"Expected a non-empty value for `config_ext_id` but received {config_ext_id!r}")
        return self._delete(
            f"/api/configs/{config_ext_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConfigDeleteResponse,
        )

    def get_schema(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """Return the JSON schema for all config models"""
        return self._get(
            "/api/configs/schema",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def get_versions(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ConfigGetVersionsResponse:
        """Returns a list of available configuration versions for the current user"""
        return self._get(
            "/api/configs/versions",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConfigGetVersionsResponse,
        )


class AsyncConfigsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncConfigsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#accessing-raw-response-data-eg-headers
        """
        return AsyncConfigsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncConfigsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#with_streaming_response
        """
        return AsyncConfigsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        agent_llm: Optional[config_create_params.AgentLlm] | Omit = omit,
        agents: Optional[config_create_params.Agents] | Omit = omit,
        chunker: Optional[ChunkerConfigParam] | Omit = omit,
        document_date_extractor_llm: Optional[DocumentDateExtractorLlmConfigParam] | Omit = omit,
        embedder: Optional[EmbedderConfigParam] | Omit = omit,
        model_citation: Optional[ModelCitationConfigParam] | Omit = omit,
        parent_message_ext_id: Optional[str] | Omit = omit,
        parser: Optional[ParserConfigParam] | Omit = omit,
        query_llm: Optional[QueryLlmConfigParam] | Omit = omit,
        reranker: Optional[RerankerConfigParam] | Omit = omit,
        retriever: Optional[RetrieverConfigParam] | Omit = omit,
        title: str | Omit = omit,
        title_llm: Optional[TitleLlmConfigParam] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ConfigCreateResponse:
        """
        Save a new configuration.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api/configs/",
            body=await async_maybe_transform(
                {
                    "agent_llm": agent_llm,
                    "agents": agents,
                    "chunker": chunker,
                    "document_date_extractor_llm": document_date_extractor_llm,
                    "embedder": embedder,
                    "model_citation": model_citation,
                    "parent_message_ext_id": parent_message_ext_id,
                    "parser": parser,
                    "query_llm": query_llm,
                    "reranker": reranker,
                    "retriever": retriever,
                    "title": title,
                    "title_llm": title_llm,
                },
                config_create_params.ConfigCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConfigCreateResponse,
        )

    async def retrieve(
        self,
        config_ext_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ConfigRetrieveResponse:
        """
        Read configurations from database to be displayed in the UI

        Args:
          config_ext_id: Config name: 'cfg-XXXXXXXX' or 'default' for system default

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not config_ext_id:
            raise ValueError(f"Expected a non-empty value for `config_ext_id` but received {config_ext_id!r}")
        return cast(
            ConfigRetrieveResponse,
            await self._get(
                f"/api/configs/{config_ext_id}",
                options=make_request_options(
                    extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
                ),
                cast_to=cast(
                    Any, ConfigRetrieveResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )

    async def delete(
        self,
        config_ext_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ConfigDeleteResponse:
        """
        Delete a specific configuration from database

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not config_ext_id:
            raise ValueError(f"Expected a non-empty value for `config_ext_id` but received {config_ext_id!r}")
        return await self._delete(
            f"/api/configs/{config_ext_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConfigDeleteResponse,
        )

    async def get_schema(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """Return the JSON schema for all config models"""
        return await self._get(
            "/api/configs/schema",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def get_versions(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ConfigGetVersionsResponse:
        """Returns a list of available configuration versions for the current user"""
        return await self._get(
            "/api/configs/versions",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConfigGetVersionsResponse,
        )


class ConfigsResourceWithRawResponse:
    def __init__(self, configs: ConfigsResource) -> None:
        self._configs = configs

        self.create = to_raw_response_wrapper(
            configs.create,
        )
        self.retrieve = to_raw_response_wrapper(
            configs.retrieve,
        )
        self.delete = to_raw_response_wrapper(
            configs.delete,
        )
        self.get_schema = to_raw_response_wrapper(
            configs.get_schema,
        )
        self.get_versions = to_raw_response_wrapper(
            configs.get_versions,
        )


class AsyncConfigsResourceWithRawResponse:
    def __init__(self, configs: AsyncConfigsResource) -> None:
        self._configs = configs

        self.create = async_to_raw_response_wrapper(
            configs.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            configs.retrieve,
        )
        self.delete = async_to_raw_response_wrapper(
            configs.delete,
        )
        self.get_schema = async_to_raw_response_wrapper(
            configs.get_schema,
        )
        self.get_versions = async_to_raw_response_wrapper(
            configs.get_versions,
        )


class ConfigsResourceWithStreamingResponse:
    def __init__(self, configs: ConfigsResource) -> None:
        self._configs = configs

        self.create = to_streamed_response_wrapper(
            configs.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            configs.retrieve,
        )
        self.delete = to_streamed_response_wrapper(
            configs.delete,
        )
        self.get_schema = to_streamed_response_wrapper(
            configs.get_schema,
        )
        self.get_versions = to_streamed_response_wrapper(
            configs.get_versions,
        )


class AsyncConfigsResourceWithStreamingResponse:
    def __init__(self, configs: AsyncConfigsResource) -> None:
        self._configs = configs

        self.create = async_to_streamed_response_wrapper(
            configs.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            configs.retrieve,
        )
        self.delete = async_to_streamed_response_wrapper(
            configs.delete,
        )
        self.get_schema = async_to_streamed_response_wrapper(
            configs.get_schema,
        )
        self.get_versions = async_to_streamed_response_wrapper(
            configs.get_versions,
        )
